@@ -18,9 +18,10 @@ import HIE.Bios.Cradle
 import Control.Monad ( forM_ )
 import Data.List ( sort, isPrefixOf )
 import Data.Typeable
+import System.Exit (ExitCode(ExitSuccess, ExitFailure))
 import System.Directory
 import System.FilePath ((</>), makeRelative)
-import System.Exit (ExitCode(ExitSuccess, ExitFailure))
+import System.Info.Extra (isWindows)
 import Control.Monad.Extra (unlessM)
 import qualified HIE.Bios.Ghc.Gap as Gap
 import Control.Monad.IO.Class
@@ -34,7 +35,7 @@ argDynamic = ["-dynamic" | Gap.hostIsDynamic]
 -- If you change this version, make sure to also update 'cabal.project'
 -- in 'tests\/projects\/cabal-with-ghc'.
 extraGhcVersion :: String
-extraGhcVersion = "9.2.8"
+extraGhcVersion = "9.4.8"
 
 extraGhc :: String
 extraGhc = "ghc-" ++ extraGhcVersion
@@ -123,7 +124,11 @@ biosTestCases =
         cradleErrorExitCode @?= ExitSuccess
         cradleErrorDependencies `shouldMatchList` []
         length cradleErrorStderr @?= 1
-        "Couldn't execute myGhc" `isPrefixOf` head cradleErrorStderr @? "Error message should contain basic information"
+        let errorCtx = head cradleErrorStderr
+        -- On windows, this error message contains '"' around the executable name
+        if isWindows
+          then "Couldn't execute \"myGhc\"" `isPrefixOf` errorCtx @? "Error message should contain error information"
+          else "Couldn't execute myGhc"     `isPrefixOf` errorCtx @? "Error message should contain error information"
   , biosTestCase "simple-bios-shell" $ runTestEnv "./simple-bios-shell" $ do
       testDirectoryM isBiosCradle "B.hs"
   , biosTestCase "simple-bios-shell-deps" $ runTestEnv "./simple-bios-shell" $ do
@@ -212,6 +217,10 @@ cabalTestCases extraGhcDep =
         assertLibDirVersionIs extraGhcVersion
         loadRuntimeGhcVersion
         assertGhcVersionIs extraGhcVersion
+        step "Find Component Options"
+        loadComponentOptions "src/MyLib.hs"
+        _ <- assertLoadSuccess
+        pure ()
     ]
   , testGroup "Cabal cabalProject"
     [ biosTestCase "cabal-with-project, options propagated" $ runTestEnv "cabal-with-project" $ do
@@ -241,7 +250,17 @@ cabalTestCases extraGhcDep =
           assertLibDirVersionIs extraGhcVersion
           loadRuntimeGhcVersion
           assertGhcVersionIs extraGhcVersion
+          step "Find Component Options"
+          loadComponentOptions "src/MyLib.hs"
+          _ <- assertLoadSuccess
+          pure ()
       ]
+    , biosTestCase "force older Cabal version in custom setup" $ runTestEnv "cabal-with-custom-setup" $ do
+        -- Specifically tests whether cabal 3.16 works as expected with
+        -- an older lib:Cabal version that doesn't support '--with-repl'.
+        -- This test doesn't hurt for other cases as well, so we enable it for
+        -- all configurations.
+        testDirectoryM isCabalCradle "src/MyLib.hs"
     ]
   ]
   where
@@ -358,7 +377,6 @@ biosTestCase name assertion = askOption @VerboseLogging (\case
   VerboseLogging verbose -> testCase name (assertion verbose)
   )
 
-
 -- ------------------------------------------------------------------
 -- Stack related helper functions
 -- ------------------------------------------------------------------
@@ -389,12 +407,14 @@ stackYaml resolver pkgs = unlines
 
 stackYamlResolver :: String
 stackYamlResolver =
-#if (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,10,0,0)))
-  "nightly-2025-04-24" -- GHC 9.10.1
+#if (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,12,0,0)))
+  "nightly-2025-08-07" -- GHC 9.12.2
+#elif (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,10,0,0)))
+  "lts-24.3" -- GHC 9.10.2
 #elif (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,8,0,0)))
   "lts-23.19" -- GHC 9.8.4
 #elif (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,6,0,0)))
-  "lts-22.43" -- GHC 9.6.6
+  "lts-22.44" -- GHC 9.6.7
 #elif (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,4,0,0)))
   "lts-21.25" -- GHC 9.4.8
 #elif (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,2,0,0)))
@@ -473,13 +493,11 @@ verboseLogging = Tasty.TestManager [Tasty.Option (Proxy :: Proxy VerboseLogging)
   \_opts _tree -> Nothing
 
 -- ------------------------------------------------------------------
--- Ignore test group if built with GHC 9.6.7 and GHC 9.12.2
+-- Ignore test group if not supported by any stackage snapshot
 -- ------------------------------------------------------------------
 
 ignoreOnUnsupportedGhc :: TestTree -> TestTree
 ignoreOnUnsupportedGhc tt =
-#if (defined(MIN_VERSION_GLASGOW_HASKELL) && (MIN_VERSION_GLASGOW_HASKELL(9,6,7,0) && !MIN_VERSION_GLASGOW_HASKELL(9,6,8,0)) || (MIN_VERSION_GLASGOW_HASKELL(9,12,2,0) && !MIN_VERSION_GLASGOW_HASKELL(9,12,3,0)))
-  ignoreTestBecause "Not supported on 9.6.7 and 9.12.2"
-#endif
+  -- Currently, all GHC versions are supported! Yay!
   tt
 
